%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% TITLE:SC
%                                  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%======================
% PATHS RELATED DATA
%======================
n_run=20;
n_linearf=6;
inputs.pathd.results_folder='SC_product_noobj_constr';        % Folder to keep re(u1+u2)lts (in Re(u1+u2)lts) for a given problem          
inputs.pathd.short_name='noisy';                      % To identify figures and reports for a given problem   
inputs.pathd.runident=strcat('run',num2str(n_run));                   % Run identifieer

%======================
% MODEL RELATED DATA
%======================

inputs.model.input_model_type='charmodelC';                % Model introduction: 'charmodelF'|'charmodelM'|'matlabmodel'|'sbmlmodel'|'fortranmodel'|                        
                                                           %                     'blackboxmodel'|'blackboxcost                             
inputs.model.n_st=11;                                       % Number of states      
inputs.model.n_par=2;                                      % Number of model parameters 
inputs.model.n_stimulus=6;                                 % Number of inputs, stimuli or control variables   
inputs.model.st_names=char('x1','x2','x3','x4'...
    ,'NADH','ATP','NAD','ADP','OBJ','NADHc','ATPc'); %,'Etot','x1c','x2c','x3c','x4c','NADc','ADPc'                % Names of the states                                              
inputs.model.par_names=char('k7','k8');                           % Names of the parameters                     
inputs.model.stimulus_names=char('e1','e2','e3','e4'...
    ,'e5','e6');                    % Names of the stimuli, inputs or controls                      

inputs.model.eqns=...                                      % Equations describing system dynamics. Time derivatives are regarded 'd'st_name''
                char( 'dx1 = -ATP*e1*x1',...
'dx2 = 2*ATP*e1*x1 - ADP*NAD*e2*x2',...
'dx3 = NAD*e4*x4 - NAD*e5*x3 - NADH*e3*x3 + ADP*NAD*e2*x2',...
'dx4 = NADH*e3*x3 - NAD*e4*x4',...
'dNADH = NAD*e4*x4 - ADP*NADH*e6 - k8*NADH + 4*NAD*e5*x3 - NADH*e3*x3 + ADP*NAD*e2*x2',...
'dATP = 3*ADP*NADH*e6 - k7*ATP - 2*ATP*e1*x1 + 2*ADP*NAD*e2*x2',...
'dNAD = k8*NADH + ADP*NADH*e6 - NAD*e4*x4 - 4*NAD*e5*x3 + NADH*e3*x3 - ADP*NAD*e2*x2',...
'dADP = k7*ATP - 3*ADP*NADH*e6 + 2*ATP*e1*x1 - 2*ADP*NAD*e2*x2',...
'dOBJ = e1 + e2 + e3 + e4 + e5 + e6',...
'dNADHc = (fmax(0.5-NADH,0))^2',...
'dATPc = (fmax(0.7-ATP,0))^2');


inputs.model.par=[3 0.1];

%==================================
% EXPERIMENTAL SCHEME RELATED DATA
%==================================
data=load('strreport_product_noisy5.mat');                          % Reads data from a .mat file

 inputs.exps.n_exp=1;                                % Number of experiments
 
 % Most inputs are common to all experiments therefore a loop over
 % experiments is defined
 for iexp=1:inputs.exps.n_exp

inputs.exps.n_obs{iexp}=8; 
inputs.exps.obs_names{iexp}=char('x1obs','x2obs','x3obs','x4obs','NADHobs','ATPobs','NADobs','ADPobs');% names of observables
inputs.exps.obs{iexp}=char('x1obs=x1','x2obs=x2','x3obs=x3','x4obs=x4','NADHobs=NADH','ATPobs=ATP','NADobs=NAD','ADPobs=ADP');
 inputs.exps.exp_y0{iexp}=[1 1 1 10 0.7 0.8 0.3 0.2 0 0 0];   % Initial conditions for each experiment       
 end

%==================================
% EXPERIMENTAL DATA RELATED INFO
%==================================
inputs.exps.data_type='real';                         % Type of data: 'pseudo'|'pseudo_pos'|'real'             
inputs.exps.noise_type='hetero_proportional';                        % Experimental noise type: Homoscedastic: 'homo'|'homo_var'(default) 


for iexp=1:inputs.exps.n_exp
    inputs.exps.t_f{iexp}=data.inputs.exps.t_f{1,iexp};
    inputs.exps.n_s{iexp}=data.inputs.exps.n_s{1,iexp};
    inputs.exps.t_s{iexp}=data.inputs.exps.t_s{1,iexp};
    inputs.exps.exp_data{iexp}=data.results.sim.exp_data{1,iexp}(:,1:inputs.exps.n_obs{iexp});
    inputs.exps.error_data{iexp}=data.results.sim.error_data{1,iexp}(:,1:inputs.exps.n_obs{iexp});
end


%==================================
% CONSTRAINTS
%==================================

inputs.iocsol.n_const_ineq_tf=2;
inputs.iocsol.const_ineq_tf=char('NADHc{1}','ATPc{1}');     % c<=0
inputs.iocsol.ineq_const_max_viol=1.0e-5;

 inputs.iocsol.n_control_const=1;
 inputs.iocsol.control_const=char('e1{1}+e2{1}+e3{1}+e4{1}+e5{1}+e6{1}-11.5');                                 % c(u)<=0
 inputs.iocsol.control_const_max_viol=1.0e-5;


%==================================
% UNKNOWNS RELATED DATA
%==================================

% GLOBAL UNKNOWNS (SAME VALUE FOR ALL EXPERIMENTS)

inputs.iocsol.id_par=char('k7','k8');                          % 'all'|User selected 
inputs.iocsol.par_max=50*ones(1,2);   % Maximum allowed values for the paramters
inputs.iocsol.par_min=1e-5*ones(1,2);       % Minimum allowed values for the parameters
inputs.iocsol.par_ref=zeros(1,2);                                  % Reference for regularization
% inputs.iocsol.par_max=10*inputs.model.par;
%TIME VARYING STIMULI/CONTROL

  inputs.iocsol.u_interp='linearf';               % [] Stimuli definition
 for iexp=1:inputs.exps.n_exp
    inputs.iocsol.n_linear{iexp}=n_linearf+1;
      inputs.iocsol.t_con{iexp}= data.inputs.exps.t_con{1,1};

 for iu=1:inputs.model.n_stimulus
    inputs.iocsol.u_min{iexp}(iu,:)=1e-7*ones(1,inputs.iocsol.n_linear{iexp});
    inputs.iocsol.u_max{iexp}(iu,:)=11.5*ones(1,inputs.iocsol.n_linear{iexp});           % Minimum and maximum value for the input
    inputs.iocsol.u_guess{iexp}(iu,:)=5.75*ones(1,inputs.iocsol.n_linear{iexp});       % Guess value for the input
 end
    inputs.iocsol.u_ref{iexp}=zeros(inputs.model.n_stimulus,inputs.iocsol.n_linear{iexp});    
 
 end
 
 %==================================
% COST FUNCTION RELATED DATA
%==================================
         
inputs.iocsol.ioccost_type='llk';                       % 'lsq' (weighted least squares default) | 'llk' (log likelihood) | 'user_PEcost' 

inputs.iocsol.llk_type='hetero';                     % [] To be defined for llk function, 'homo' | 'homo_var' | 'hetero' 

%==================================
% REGULARIZATION PARAMETERS
%==================================
inputs.model.alpha=0.0;   % Parameter value to handle control regularization (any real number)
%                         % 0: means no regularization
inputs.model.beta=0.0;    % Paremeter value to handle regularization in PE (any real number)
                        % 0: means no regularization                                                                         
inputs.iocsol.uttReg=0.00;

%==================================
% NUMERICAL METHODS RELATED DATA
%==================================
%
 
% % SIMULATION
inputs.ivpsol.ivpsolver='cvodes';                      % [] IVP solver: 'cvodes'(default, C)|'ode15s' (default, MATLAB, sbml)|'ode113'|'ode45'
inputs.ivpsol.rtol=1.0D-7;                             % [] IVP solver integration tolerances
inputs.ivpsol.atol=1.0D-7; 
inputs.ivpsol.senssolver='cvodes'; 
 
% 
% OPTIMIZATION
%

inputs.nlpsol.nlpsolver='eSS';             % In this case the problem will be solved with eSS
inputs.nlpsol.eSS.iterprint=1;             % Print each iteration on screen: 0-Deactivated
                                           % 1-Activated (1, default)
inputs.nlpsol.eSS.local.solver='fsqp';     % Choose local solver
                                           % 0: Local search deactivated
                                           % 'fminsearch','nomad', 'dhc'
                                           % 'fmincon','solnp','ipopt'
                                           % for PE:'n2fb','dn2fb','lsqnonlin','nl2sol'
inputs.nlpsol.eSS.local.iterprint=0;       % Print each iteration on screen: 0-Deactivated
                                           % 1-Activated
inputs.nlpsol.eSS.local.finish='fsqp';                                           

inputs.nlpsol.eSS.log_var =[1:2+7*6];                     % Decision variables to be considered in log-scale. Suitable for this problem with parameters
                                                     % ranging from 0 to 1.

inputs.nlpsol.eSS.maxeval = 5500000;
inputs.nlpsol.eSS.maxtime = 3600*1;
inputs.nlpsol.eSS.local.nl2sol.display = 1;
inputs.plotd.figsave=1;

% inputs.IDOsol=rmfield(inputs.iocsol,'ioccost_type');inputs.IDOsol.IDOcost_type=inputs.iocsol.ioccost_type;inputs=rmfield(inputs,'iocsol');